@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2006-2015 Henning Norén
+ * Copyright (C) 2006-2019 Henning Norén
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,14 +25,10 @@ void
 freeEncData(EncData *e) {
   if(!e)
     return;
-  if(e->o_string)
-    free(e->o_string);
-  if(e->u_string)
-    free(e->u_string);
-  if(e->fileID)
-    free(e->fileID);
-  if(e->s_handler)
-    free(e->s_handler);
+  free(e->o_string);
+  free(e->u_string);
+  free(e->fileID);
+  free(e->s_handler);
   free(e);
 }
 
