@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2006 Henning Norén
+ * Copyright (C) 2006-2014 Henning Norén
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,7 +24,13 @@
 void 
 md5(const uint8_t *msg, const unsigned int msgLen, uint8_t *digest);
 
+/** init function for md5_50 which chooses a md5_50 optimised for msgLen, 
+    if one is available */
 void
-md5_50(uint8_t *msg);
+md5_50_init(const unsigned int msgLen);
+
+/** md5_50 is basically for(i=0; i<50; i++) { md5(msg, msgLen, msg); } */
+void
+md5_50(uint8_t *msg, const unsigned int msgLen);
 
 #endif /** _MD5_H_ */
