@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2006-2017 Henning Norén
+ * Copyright (C) 2006-2019 Henning Norén
  * Copyright (C) 1996-2005 Glyph & Cog, LLC.
  * 
  * This program is free software; you can redistribute it and/or
@@ -48,7 +48,7 @@ pad[32] = {
 /** buffers for stuff that we can precompute before the actual cracking */
 static uint8_t *encKeyWorkSpace;
 static uint8_t password_user[40];  /** need to cover 32 char + salt */
-static uint8_t *rev3TestKey;
+static const uint8_t *rev3TestKey;
 static unsigned int ekwlen;
 
 /** points to the current password in clear-text */
