@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2006-2019 Henning Norén
+ * Copyright (C) 2006-2020 Henning Norén
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -188,13 +188,13 @@ openPDF(FILE *file, EncData *e) {
     major_v = parseInt(file);
     if(getc(file) == '.')
       minor_v = parseInt(file);
-    if(major_v >= 0)
+    if(major_v >= 0 && minor_v >=0)
       ret = true;
   }
 
   if(ret) {
-    e->version_major = major_v;
-    e->version_minor = minor_v;
+    e->version_major = (unsigned)major_v;
+    e->version_minor = (unsigned)minor_v;
   } 
   return ret;
 }
@@ -392,6 +392,9 @@ findTrailerDict(FILE *file, EncData *e) {
 	  ch = getc(file);
 	  /**printf("found a name: %c\n", ch);*/
 	  if(e_pos < 0 && ch == 'E' && isWord(file, "ncrypt")) {
+	    ch = getc(file);
+	    if(!isWhiteSpace(ch))
+	      continue;
 	    e_pos = parseIntWithC(file,parseWhiteSpace(file));
 	    if(e_pos >= 0) {
 	      /**
@@ -500,6 +503,9 @@ findTrailer(FILE *file, EncData *e) {
 	    ch = getc(file);
 	    /**printf("found a name: %c\n", ch);*/
 	    if(e_pos < 0 && ch == 'E' && isWord(file, "ncrypt")) {
+	      ch = getc(file);
+	      if(!isWhiteSpace(ch))
+		continue;
 	      e_pos = parseIntWithC(file,parseWhiteSpace(file));
 	      if(e_pos >= 0) {
 		/**
@@ -652,7 +658,7 @@ parseEncrypObject(FILE *file, EncData *e) {
 	    if(tmp_l > 256 || tmp_l < 40 || ((tmp_l % 8) != 0)) {
 	      fprintf(stderr, "WARNING: Length = %d\n", tmp_l);
 	    }
-	    e->length = tmp_l;
+	    e->length = (unsigned)tmp_l;
 	  }
 	  fl = true;
 	}
