@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2006-2017 Henning Norén
+ * Copyright (C) 2006-2020 Henning Norén
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -188,13 +188,13 @@ rc4Decrypt128b(const uint8_t *key, const uint8_t *bs,
   }
 }
 
-static int keyLen;
+static unsigned int keyLen;
 
 static void
 rc4DecryptArb(const uint8_t *key, const uint8_t *bs,
 	      const unsigned int len, uint8_t *out) {
   uint8_t state[256];
-  register unsigned int i;
+  register int i;
   register uint8_t j, tmp;
   
   /** initialize the state */
@@ -228,7 +228,7 @@ rc4Decrypt(const uint8_t *key, const uint8_t *bs,
 /** sets which function the wrapper should call */
 bool
 setrc4DecryptMethod(const unsigned int length) {
-  if(length > 255 || length < 40 || length % 8 != 0)
+  if(length > 128 || length < 40 || length % 8 != 0)
     return false;
 
   if(length == 128) {
